//go:build go1.16
// +build go1.16

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

package generated

import (
	"context"
	"net/http"
	"reflect"

	"github.com/Azure/azure-sdk-for-go/sdk/azcore/policy"
	"github.com/Azure/azure-sdk-for-go/sdk/azcore/runtime"
)

// AzureAppConfigurationClientGetKeyValuesPager provides operations for iterating over paged responses.
type AzureAppConfigurationClientGetKeyValuesPager struct {
	client    *AzureAppConfigurationClient
	current   AzureAppConfigurationClientGetKeyValuesResponse
	err       error
	requester func(context.Context) (*policy.Request, error)
	advancer  func(context.Context, AzureAppConfigurationClientGetKeyValuesResponse) (*policy.Request, error)
}

// Err returns the last error encountered while paging.
func (p *AzureAppConfigurationClientGetKeyValuesPager) Err() error {
	return p.err
}

// NextPage returns true if the pager advanced to the next page.
// Returns false if there are no more pages or an error occurred.
func (p *AzureAppConfigurationClientGetKeyValuesPager) NextPage(ctx context.Context) bool {
	var req *policy.Request
	var err error
	if !reflect.ValueOf(p.current).IsZero() {
		if p.current.KeyValueListResult.NextLink == nil || len(*p.current.KeyValueListResult.NextLink) == 0 {
			return false
		}
		req, err = p.advancer(ctx, p.current)
	} else {
		req, err = p.requester(ctx)
	}
	if err != nil {
		p.err = err
		return false
	}
	resp, err := p.client.pl.Do(req)
	if err != nil {
		p.err = err
		return false
	}
	if !runtime.HasStatusCode(resp, http.StatusOK) {
		p.err = runtime.NewResponseError(resp)
		return false
	}
	result, err := p.client.getKeyValuesHandleResponse(resp)
	if err != nil {
		p.err = err
		return false
	}
	p.current = result
	return true
}

// PageResponse returns the current AzureAppConfigurationClientGetKeyValuesResponse page.
func (p *AzureAppConfigurationClientGetKeyValuesPager) PageResponse() AzureAppConfigurationClientGetKeyValuesResponse {
	return p.current
}

// AzureAppConfigurationClientGetKeysPager provides operations for iterating over paged responses.
type AzureAppConfigurationClientGetKeysPager struct {
	client    *AzureAppConfigurationClient
	current   AzureAppConfigurationClientGetKeysResponse
	err       error
	requester func(context.Context) (*policy.Request, error)
	advancer  func(context.Context, AzureAppConfigurationClientGetKeysResponse) (*policy.Request, error)
}

// Err returns the last error encountered while paging.
func (p *AzureAppConfigurationClientGetKeysPager) Err() error {
	return p.err
}

// NextPage returns true if the pager advanced to the next page.
// Returns false if there are no more pages or an error occurred.
func (p *AzureAppConfigurationClientGetKeysPager) NextPage(ctx context.Context) bool {
	var req *policy.Request
	var err error
	if !reflect.ValueOf(p.current).IsZero() {
		if p.current.KeyListResult.NextLink == nil || len(*p.current.KeyListResult.NextLink) == 0 {
			return false
		}
		req, err = p.advancer(ctx, p.current)
	} else {
		req, err = p.requester(ctx)
	}
	if err != nil {
		p.err = err
		return false
	}
	resp, err := p.client.pl.Do(req)
	if err != nil {
		p.err = err
		return false
	}
	if !runtime.HasStatusCode(resp, http.StatusOK) {
		p.err = runtime.NewResponseError(resp)
		return false
	}
	result, err := p.client.getKeysHandleResponse(resp)
	if err != nil {
		p.err = err
		return false
	}
	p.current = result
	return true
}

// PageResponse returns the current AzureAppConfigurationClientGetKeysResponse page.
func (p *AzureAppConfigurationClientGetKeysPager) PageResponse() AzureAppConfigurationClientGetKeysResponse {
	return p.current
}

// AzureAppConfigurationClientGetLabelsPager provides operations for iterating over paged responses.
type AzureAppConfigurationClientGetLabelsPager struct {
	client    *AzureAppConfigurationClient
	current   AzureAppConfigurationClientGetLabelsResponse
	err       error
	requester func(context.Context) (*policy.Request, error)
	advancer  func(context.Context, AzureAppConfigurationClientGetLabelsResponse) (*policy.Request, error)
}

// Err returns the last error encountered while paging.
func (p *AzureAppConfigurationClientGetLabelsPager) Err() error {
	return p.err
}

// NextPage returns true if the pager advanced to the next page.
// Returns false if there are no more pages or an error occurred.
func (p *AzureAppConfigurationClientGetLabelsPager) NextPage(ctx context.Context) bool {
	var req *policy.Request
	var err error
	if !reflect.ValueOf(p.current).IsZero() {
		if p.current.LabelListResult.NextLink == nil || len(*p.current.LabelListResult.NextLink) == 0 {
			return false
		}
		req, err = p.advancer(ctx, p.current)
	} else {
		req, err = p.requester(ctx)
	}
	if err != nil {
		p.err = err
		return false
	}
	resp, err := p.client.pl.Do(req)
	if err != nil {
		p.err = err
		return false
	}
	if !runtime.HasStatusCode(resp, http.StatusOK) {
		p.err = runtime.NewResponseError(resp)
		return false
	}
	result, err := p.client.getLabelsHandleResponse(resp)
	if err != nil {
		p.err = err
		return false
	}
	p.current = result
	return true
}

// PageResponse returns the current AzureAppConfigurationClientGetLabelsResponse page.
func (p *AzureAppConfigurationClientGetLabelsPager) PageResponse() AzureAppConfigurationClientGetLabelsResponse {
	return p.current
}

// AzureAppConfigurationClientGetRevisionsPager provides operations for iterating over paged responses.
type AzureAppConfigurationClientGetRevisionsPager struct {
	client    *AzureAppConfigurationClient
	current   AzureAppConfigurationClientGetRevisionsResponse
	err       error
	requester func(context.Context) (*policy.Request, error)
	advancer  func(context.Context, AzureAppConfigurationClientGetRevisionsResponse) (*policy.Request, error)
}

// Err returns the last error encountered while paging.
func (p *AzureAppConfigurationClientGetRevisionsPager) Err() error {
	return p.err
}

// NextPage returns true if the pager advanced to the next page.
// Returns false if there are no more pages or an error occurred.
func (p *AzureAppConfigurationClientGetRevisionsPager) NextPage(ctx context.Context) bool {
	var req *policy.Request
	var err error
	if !reflect.ValueOf(p.current).IsZero() {
		if p.current.KeyValueListResult.NextLink == nil || len(*p.current.KeyValueListResult.NextLink) == 0 {
			return false
		}
		req, err = p.advancer(ctx, p.current)
	} else {
		req, err = p.requester(ctx)
	}
	if err != nil {
		p.err = err
		return false
	}
	resp, err := p.client.pl.Do(req)
	if err != nil {
		p.err = err
		return false
	}
	if !runtime.HasStatusCode(resp, http.StatusOK) {
		p.err = runtime.NewResponseError(resp)
		return false
	}
	result, err := p.client.getRevisionsHandleResponse(resp)
	if err != nil {
		p.err = err
		return false
	}
	p.current = result
	return true
}

// PageResponse returns the current AzureAppConfigurationClientGetRevisionsResponse page.
func (p *AzureAppConfigurationClientGetRevisionsPager) PageResponse() AzureAppConfigurationClientGetRevisionsResponse {
	return p.current
}
